XboxProfile class

Annotations
  • @JsonSerializable.new()

Constructors

XboxProfile({required String displayName, required String xuid, String? profilePicture})
const
XboxProfile.fromJson(Map<String, dynamic> json)
Converts a JSON map to a XboxProfile.
factory

Properties

displayName String
final
hashCode int
The hash code for this object.
no setterinherited
profilePicture String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xuid String
final

Methods

copyWith({String? displayName, String? xuid, String? profilePicture}) XboxProfile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this XboxProfile to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited